Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(659)

Unified Diff: mandoline/ui/phone_ui/phone_browser_application_delegate.cc

Issue 1351013002: Revert of Mandoline UI Process: Update namespaces and file names (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 5 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « mandoline/ui/phone_ui/phone_browser_application_delegate.h ('k') | mojo/cc/output_surface_mojo.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: mandoline/ui/phone_ui/phone_browser_application_delegate.cc
diff --git a/mandoline/ui/phone_ui/phone_browser_application_delegate.cc b/mandoline/ui/phone_ui/phone_browser_application_delegate.cc
index db21dde16febbd830c3b7eaa27684eb622dec49f..93307aad9d51f0956e7db6bd9e79a584bb9fedbc 100644
--- a/mandoline/ui/phone_ui/phone_browser_application_delegate.cc
+++ b/mandoline/ui/phone_ui/phone_browser_application_delegate.cc
@@ -47,7 +47,7 @@
break;
}
}
- mus::CreateSingleViewTreeHost(app_, this, &host_);
+ mojo::CreateSingleViewTreeHost(app_, this, &host_);
}
bool PhoneBrowserApplicationDelegate::ConfigureIncomingConnection(
@@ -66,9 +66,9 @@
}
////////////////////////////////////////////////////////////////////////////////
-// PhoneBrowserApplicationDelegate, mus::ViewTreeDelegate implementation:
+// PhoneBrowserApplicationDelegate, mojo::ViewTreeDelegate implementation:
-void PhoneBrowserApplicationDelegate::OnEmbed(mus::View* root) {
+void PhoneBrowserApplicationDelegate::OnEmbed(mojo::View* root) {
CHECK(!root_);
root_ = root;
content_ = root->connection()->CreateView();
@@ -83,13 +83,14 @@
}
void PhoneBrowserApplicationDelegate::OnConnectionLost(
- mus::ViewTreeConnection* connection) {}
+ mojo::ViewTreeConnection* connection) {
+}
////////////////////////////////////////////////////////////////////////////////
// PhoneBrowserApplicationDelegate, mus::ViewObserver implementation:
void PhoneBrowserApplicationDelegate::OnViewBoundsChanged(
- mus::View* view,
+ mojo::View* view,
const mojo::Rect& old_bounds,
const mojo::Rect& new_bounds) {
CHECK_EQ(view, root_);
@@ -83,13 +83,14 @@
////////////////////////////////////////////////////////////////////////////////
-// PhoneBrowserApplicationDelegate, mus::ViewObserver implementation:
+// PhoneBrowserApplicationDelegate, mojo::ViewObserver implementation:
void PhoneBrowserApplicationDelegate::OnViewBoundsChanged(
« no previous file with comments | « mandoline/ui/phone_ui/phone_browser_application_delegate.h ('k') | mojo/cc/output_surface_mojo.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698